@@ -82,7 +82,7 @@ class Connection:
         answer = {}
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[ 500, 502, 503, 504 ])
         session = requests.Session()
-        session.mount(HTTPAdapter(max_retries=retries))
+        session.mount('https://',HTTPAdapter(max_retries=retries))
         url_callback = f'{UPDATE_URL}{message.get("liveness_id")}/'
         try:
             # Download video file from video_path in Google Storage
